summaryrefslogtreecommitdiffstats
path: root/app/resource_bundle_win.cc
diff options
context:
space:
mode:
authortommi@chromium.org <tommi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-25 19:06:57 +0000
committertommi@chromium.org <tommi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-25 19:06:57 +0000
commit76180ea4287b9458d97f8d547daf785bf136fba1 (patch)
treea8eeb50c3f486c330ea07530e1a77f126e195f55 /app/resource_bundle_win.cc
parent64134fec4ed2f78dde84c6533dd2cc962f365ae6 (diff)
downloadchromium_src-76180ea4287b9458d97f8d547daf785bf136fba1.zip
chromium_src-76180ea4287b9458d97f8d547daf785bf136fba1.tar.gz
chromium_src-76180ea4287b9458d97f8d547daf785bf136fba1.tar.bz2
Load chrome.dll as a resource dll so that resources can be loaded by the browser.
TEST=fixes net tests for chrome frame BUG=none Review URL: http://codereview.chromium.org/437050 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@33094 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'app/resource_bundle_win.cc')
-rw-r--r--app/resource_bundle_win.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/resource_bundle_win.cc b/app/resource_bundle_win.cc
index 63645d4..ec306ef 100644
--- a/app/resource_bundle_win.cc
+++ b/app/resource_bundle_win.cc
@@ -39,8 +39,8 @@ ResourceBundle::~ResourceBundle() {
}
void ResourceBundle::LoadResources(const std::wstring& pref_locale) {
- // As a convenience, set resources_data_ to the current module.
- resources_data_ = _AtlBaseModule.GetModuleInstance();
+ // As a convenience, set resources_data_ to the current resource module.
+ resources_data_ = _AtlBaseModule.GetResourceInstance();
DCHECK(NULL == locale_resources_data_) << "locale dll already loaded";
const FilePath& locale_path = GetLocaleFilePath(pref_locale);